#! /bin/bash -xe
echo "Logging to /var/log/rightlink.log" 1>&2
exec > >(tee -a /var/log/rightlink.log)
exec 2>&1
touch /var/log/rightlink.log && chmod 600 /var/log/rightlink.log

# Determine if /usr/local/bin is read-only. If so, use /opt/bin to install executables
mkdir -p /usr/local/bin || true
[ -w /usr/local/bin ] && BIN_DIR=/usr/local/bin || BIN_DIR=/opt/bin

URL=https://rightlink.rightscale.com/rll/10.6.4/rightlink.gz
RL=$BIN_DIR/rightlink
RSC=$BIN_DIR/rsc

if [[ ! "$PATH" =~ $BIN_DIR ]]; then
  export PATH="$PATH:$BIN_DIR"
fi


# We need to use the key=value form of user-data on GCE, sigh!
export client_id=$(curl http://metadata/computeMetadata/v1/instance/attributes/RS_rn_id -H "Metadata-Flavor: Google")
export client_secret=$(curl http://metadata/computeMetadata/v1/instance/attributes/RS_rn_auth -H "Metadata-Flavor: Google")
export api_hostname=$(curl http://metadata/computeMetadata/v1/instance/attributes/RS_server -H "Metadata-Flavor: Google")
export account=$(curl http://metadata/computeMetadata/v1/instance/attributes/RS_account -H "Metadata-Flavor: Google")
for var in $(curl http://metadata/computeMetadata/v1/instance/attributes/ -H "Metadata-Flavor: Google"); do
  if [[ "$var" == "RS_http_proxy" ]]; then
    export http_proxy=$(curl http://metadata/computeMetadata/v1/instance/attributes/RS_http_proxy -H "Metadata-Flavor: Google")
  fi
  if [[ "$var" == "RS_http_no_proxy" ]]; then
    export no_proxy=$(curl http://metadata/computeMetadata/v1/instance/attributes/RS_http_no_proxy -H "Metadata-Flavor: Google")
  fi
done

# We check this early to avoid unneeded s3 calls and avoid creating a rightscale
# user if one wasn't specified previously such as after enablement
if [[ -x "$RL" && -x "$RSC" ]]; then
  echo "RightLink is already installed in $RL"
  echo "Skipping re-installation. RightLink should be started by existing init script."
  exit 0
fi

echo "`date` Starting Launch-Time RightLink 10.6.4 download and install."

# ===== Download and Expand RightLink
echo "Downloading tarball from $URL, extracting into /tmp/rightlink"
cd /tmp
rm -rf rightlink rightlink.tgz
for s in 2 4 6 8 12 16 20 24 32 64; do
  if wget -q -O rightlink.tgz $URL || curl -s -o rightlink.tgz $URL ; then
    break
  fi
  echo "`date` Download error, sleeping $s seconds"
  sleep $s
done
# Expand the archive into /tmp/rightlink
tar zxf rightlink.tgz
cd rightlink

# ===== Install RSC command line tool


# Put the binary into a bin directory
mkdir -p ${RSC%/*}
mv rsc $RSC
chmod +x $RSC

echo "$(rsc --version) command line API tool installed."

# ===== Install RightLink

chmod +x ./install.sh
exec ./install.sh

echo "`date` Launch-Time RightLink 10.6.4 download and install complete."
